@@ -39,6 +39,18 @@ impl InstallBackend {
 
     fn version(&self, python_path: &Path) -> Result<semver::Version> {
         let mut cmd = self.make_command(python_path);
+
+        // Newer versions of uv no longer support `uv pip --version`, and instead
+        // require that we use `uv --version`. This is a workaround to get the
+        // version of the install backend for both old and new versions of uv.
+        cmd = match self {
+            InstallBackend::Pip { .. } => cmd,
+            InstallBackend::Uv { path, args } => {
+                let mut cmd = Command::new(path);
+                cmd.args(args);
+                cmd
+            }
+        };
         let output = cmd
             .arg("--version")
             .output()
@@ -50,7 +62,7 @@ impl InstallBackend {
         let stdout = str::from_utf8(&output.stdout)?;
         let re = match self {
             InstallBackend::Pip { .. } => Regex::new(r"pip ([\w\.]+).*"),
-            InstallBackend::Uv { .. } => Regex::new(r"uv-pip ([\w\.]+).*"),
+            InstallBackend::Uv { .. } => Regex::new(r"uv ([\w\.]+).*"),
         };
         if let Some(captures) = re.expect("regex should be valid").captures(stdout) {
             Ok(semver::Version::parse(&captures[1])
@@ -376,8 +388,8 @@ pub fn develop(develop_options: DevelopOptions, venv_dir: &Path) -> Result<()> {
         cargo_options,
         uv,
     } = develop_options;
-    let mut target_triple = cargo_options.target.as_ref().map(|x| x.to_string());
-    let target = Target::from_target_triple(cargo_options.target)?;
+    let mut target_triple = cargo_options.target.clone();
+    let target = Target::from_target_triple(cargo_options.target.as_ref())?;
     let python = target.get_venv_python(venv_dir);
 
     // check python platform and architecture
@@ -404,6 +416,7 @@ pub fn develop(develop_options: DevelopOptions, venv_dir: &Path) -> Result<()> {
             target: target_triple,
             ..cargo_options
         },
+        compression_level: 6,
     };
 
     let build_context = build_options
@@ -458,7 +471,9 @@ pub fn develop(develop_options: DevelopOptions, venv_dir: &Path) -> Result<()> {
         }
     };
 
-    install_dependencies(&build_context, &extras, &python, venv_dir, &install_backend)?;
+    if !skip_install {
+        install_dependencies(&build_context, &extras, &python, venv_dir, &install_backend)?;
+    }
 
     let wheels = build_context.build_wheels()?;
     if !skip_install {
