@@ -23,15 +23,15 @@
 
 #![deny(missing_docs)]
 
-pub use crate::bridge::{Bindings, BridgeModel};
+pub use crate::bridge::{Abi3Version, BridgeModel, PyO3, PyO3Crate};
 pub use crate::build_context::{BuildContext, BuiltWheelMetadata};
-pub use crate::build_options::{BuildOptions, CargoOptions};
+pub use crate::build_options::{BuildOptions, CargoOptions, TargetTriple};
 pub use crate::cargo_toml::CargoToml;
 pub use crate::compile::{compile, BuildArtifact};
 pub use crate::develop::{develop, DevelopOptions};
 #[cfg(feature = "schemars")]
 pub use crate::generate_json_schema::{generate_json_schema, GenerateJsonSchemaOptions, Mode};
-pub use crate::metadata::{Metadata23, WheelMetadata};
+pub use crate::metadata::{Metadata24, WheelMetadata};
 pub use crate::module_writer::{
     write_dist_info, ModuleWriter, PathWriter, SDistWriter, WheelWriter,
 };
